summaryrefslogtreecommitdiff
path: root/include/channels.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/channels.h')
-rw-r--r--include/channels.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/include/channels.h b/include/channels.h
index 0d4c4813c..2042df220 100644
--- a/include/channels.h
+++ b/include/channels.h
@@ -137,12 +137,12 @@ class CoreExport Channel : public Extensible
std::string name; /* CHANMAX */
/** Modes for the channel.
* This is not a null terminated string! It is a hash where
* each item in it represents if a mode is set. For example
* for mode +A, index 0. Use modechar-65 to calculate which
* field to check.
*/
- unsigned char modes[64];
+ std::bitset<64> modes;
/** User lists.
* There are four user lists, one for
@@ -137,12 +137,12 @@ class CoreExport Channel : public Extensible
std::string name; /* CHANMAX */
/** Modes for the channel.
- * This is not a null terminated string! It is a hash where
+ * This is not a null terminated string! It is a bitset where
* each item in it represents if a mode is set. For example
* for mode +A, index 0. Use modechar-65 to calculate which